@@ -58,7 +58,7 @@ class DBConnect():
             logging.warning(str_data)
             abort(Response(str_data, 500, {}))
 
-    def find_paging(self, parameter: Parameter) -> tuple:
+    def find_paging(self, parameter: Parameter) -> dict:
         parameter.verification(
             checking=parameter.param_url,
             verify={
@@ -109,7 +109,14 @@ class DBConnect():
         find_data = self.mongo_collection.find(find_dict)
         records_filtered = find_data.count()
         if not records_filtered:
-            return '请求数据不存在', 204, [('Content-Type', 'text/plain; charset=utf-8')]
+            logging.warning('请求数据不存在: {0}'.format(err))
+            dict_data = {
+                'records_total': [],
+                'records_filtered': 0,
+                'query_result': 0,
+            }
+            abort(Response(dict_data, 204, {
+                  'Content-Type', 'text/plain; charset=utf-8'}))
         if sort_list:
             find_data.sort(sort_list).limit(
                 page_size).skip(page_size*current)
@@ -124,4 +131,4 @@ class DBConnect():
             'records_total': self.mongo_collection.estimated_document_count(),
             'records_filtered': records_filtered,
             'query_result': query_result,
-        }, 200, [('Content-Type', 'application/json; charset=utf-8')]
+        }
